==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/IngressSpecFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressSpecFluent<A extends io.fabric8.openshift.api.model.IngressSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getAppsDomain();
  public A withAppsDomain(java.lang.String appsDomain);
  public java.lang.Boolean hasAppsDomain();
  
  /**
   * Method is deprecated. use withAppsDomain instead.
   */
  @java.lang.Deprecated
  public A withNewAppsDomain(java.lang.String arg0);
  public A addToComponentRoutes(java.lang.Integer index,io.fabric8.openshift.api.model.ComponentRouteSpec item);
  public A setToComponentRoutes(java.lang.Integer index,io.fabric8.openshift.api.model.ComponentRouteSpec item);
  public A addToComponentRoutes(io.fabric8.openshift.api.model.ComponentRouteSpec... items);
  public A addAllToComponentRoutes(java.util.Collection<io.fabric8.openshift.api.model.ComponentRouteSpec> items);
  public A removeFromComponentRoutes(io.fabric8.openshift.api.model.ComponentRouteSpec... items);
  public A removeAllFromComponentRoutes(java.util.Collection<io.fabric8.openshift.api.model.ComponentRouteSpec> items);
  public A removeMatchingFromComponentRoutes(java.util.function.Predicate<io.fabric8.openshift.api.model.ComponentRouteSpecBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildComponentRoutes instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.ComponentRouteSpec> getComponentRoutes();
  public java.util.List<io.fabric8.openshift.api.model.ComponentRouteSpec> buildComponentRoutes();
  public io.fabric8.openshift.api.model.ComponentRouteSpec buildComponentRoute(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ComponentRouteSpec buildFirstComponentRoute();
  public io.fabric8.openshift.api.model.ComponentRouteSpec buildLastComponentRoute();
  public io.fabric8.openshift.api.model.ComponentRouteSpec buildMatchingComponentRoute(java.util.function.Predicate<io.fabric8.openshift.api.model.ComponentRouteSpecBuilder> predicate);
  public java.lang.Boolean hasMatchingComponentRoute(java.util.function.Predicate<io.fabric8.openshift.api.model.ComponentRouteSpecBuilder> predicate);
  public A withComponentRoutes(java.util.List<io.fabric8.openshift.api.model.ComponentRouteSpec> componentRoutes);
  public A withComponentRoutes(io.fabric8.openshift.api.model.ComponentRouteSpec... componentRoutes);
  public java.lang.Boolean hasComponentRoutes();
  public io.fabric8.openshift.api.model.IngressSpecFluent.ComponentRoutesNested<A> addNewComponentRoute();
  public io.fabric8.openshift.api.model.IngressSpecFluent.ComponentRoutesNested<A> addNewComponentRouteLike(io.fabric8.openshift.api.model.ComponentRouteSpec item);
  public io.fabric8.openshift.api.model.IngressSpecFluent.ComponentRoutesNested<A> setNewComponentRouteLike(java.lang.Integer index,io.fabric8.openshift.api.model.ComponentRouteSpec item);
  public io.fabric8.openshift.api.model.IngressSpecFluent.ComponentRoutesNested<A> editComponentRoute(java.lang.Integer index);
  public io.fabric8.openshift.api.model.IngressSpecFluent.ComponentRoutesNested<A> editFirstComponentRoute();
  public io.fabric8.openshift.api.model.IngressSpecFluent.ComponentRoutesNested<A> editLastComponentRoute();
  public io.fabric8.openshift.api.model.IngressSpecFluent.ComponentRoutesNested<A> editMatchingComponentRoute(java.util.function.Predicate<io.fabric8.openshift.api.model.ComponentRouteSpecBuilder> predicate);
  public java.lang.String getDomain();
  public A withDomain(java.lang.String domain);
  public java.lang.Boolean hasDomain();
  
  /**
   * Method is deprecated. use withDomain instead.
   */
  @java.lang.Deprecated
  public A withNewDomain(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ComponentRoutesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ComponentRouteSpecFluent<io.fabric8.openshift.api.model.IngressSpecFluent.ComponentRoutesNested<N>>{
    public N and();
    public N endComponentRoute();
    
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/IngressSpecFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressSpecFluent<A extends io.fabric8.openshift.api.model.IngressSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getAppsDomain();
  public A withAppsDomain(java.lang.String appsDomain);
  public java.lang.Boolean hasAppsDomain();
  
  /**
   * Method is deprecated. use withAppsDomain instead.
   */
  @java.lang.Deprecated
  public A withNewAppsDomain(java.lang.String arg0);
  public A addToComponentRoutes(java.lang.Integer index,io.fabric8.openshift.api.model.ComponentRouteSpec item);
  public A setToComponentRoutes(java.lang.Integer index,io.fabric8.openshift.api.model.ComponentRouteSpec item);
  public A addToComponentRoutes(io.fabric8.openshift.api.model.ComponentRouteSpec... items);
  public A addAllToComponentRoutes(java.util.Collection<io.fabric8.openshift.api.model.ComponentRouteSpec> items);
  public A removeFromComponentRoutes(io.fabric8.openshift.api.model.ComponentRouteSpec... items);
  public A removeAllFromComponentRoutes(java.util.Collection<io.fabric8.openshift.api.model.ComponentRouteSpec> items);
  public A removeMatchingFromComponentRoutes(java.util.function.Predicate<io.fabric8.openshift.api.model.ComponentRouteSpecBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildComponentRoutes instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.ComponentRouteSpec> getComponentRoutes();
  public java.util.List<io.fabric8.openshift.api.model.ComponentRouteSpec> buildComponentRoutes();
  public io.fabric8.openshift.api.model.ComponentRouteSpec buildComponentRoute(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ComponentRouteSpec buildFirstComponentRoute();
  public io.fabric8.openshift.api.model.ComponentRouteSpec buildLastComponentRoute();
  public io.fabric8.openshift.api.model.ComponentRouteSpec buildMatchingComponentRoute(java.util.function.Predicate<io.fabric8.openshift.api.model.ComponentRouteSpecBuilder> predicate);
  public java.lang.Boolean hasMatchingComponentRoute(java.util.function.Predicate<io.fabric8.openshift.api.model.ComponentRouteSpecBuilder> predicate);
  public A withComponentRoutes(java.util.List<io.fabric8.openshift.api.model.ComponentRouteSpec> componentRoutes);
  public A withComponentRoutes(io.fabric8.openshift.api.model.ComponentRouteSpec... componentRoutes);
  public java.lang.Boolean hasComponentRoutes();
  public io.fabric8.openshift.api.model.IngressSpecFluent.ComponentRoutesNested<A> addNewComponentRoute();
  public io.fabric8.openshift.api.model.IngressSpecFluent.ComponentRoutesNested<A> addNewComponentRouteLike(io.fabric8.openshift.api.model.ComponentRouteSpec item);
  public io.fabric8.openshift.api.model.IngressSpecFluent.ComponentRoutesNested<A> setNewComponentRouteLike(java.lang.Integer index,io.fabric8.openshift.api.model.ComponentRouteSpec item);
  public io.fabric8.openshift.api.model.IngressSpecFluent.ComponentRoutesNested<A> editComponentRoute(java.lang.Integer index);
  public io.fabric8.openshift.api.model.IngressSpecFluent.ComponentRoutesNested<A> editFirstComponentRoute();
  public io.fabric8.openshift.api.model.IngressSpecFluent.ComponentRoutesNested<A> editLastComponentRoute();
  public io.fabric8.openshift.api.model.IngressSpecFluent.ComponentRoutesNested<A> editMatchingComponentRoute(java.util.function.Predicate<io.fabric8.openshift.api.model.ComponentRouteSpecBuilder> predicate);
  public java.lang.String getDomain();
  public A withDomain(java.lang.String domain);
  public java.lang.Boolean hasDomain();
  
  /**
   * Method is deprecated. use withDomain instead.
   */
  @java.lang.Deprecated
  public A withNewDomain(java.lang.String arg0);
  public A addToRequiredHSTSPolicies(java.lang.Integer index,io.fabric8.openshift.api.model.RequiredHSTSPolicy item);
  public A setToRequiredHSTSPolicies(java.lang.Integer index,io.fabric8.openshift.api.model.RequiredHSTSPolicy item);
  public A addToRequiredHSTSPolicies(io.fabric8.openshift.api.model.RequiredHSTSPolicy... items);
  public A addAllToRequiredHSTSPolicies(java.util.Collection<io.fabric8.openshift.api.model.RequiredHSTSPolicy> items);
  public A removeFromRequiredHSTSPolicies(io.fabric8.openshift.api.model.RequiredHSTSPolicy... items);
  public A removeAllFromRequiredHSTSPolicies(java.util.Collection<io.fabric8.openshift.api.model.RequiredHSTSPolicy> items);
  public A removeMatchingFromRequiredHSTSPolicies(java.util.function.Predicate<io.fabric8.openshift.api.model.RequiredHSTSPolicyBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRequiredHSTSPolicies instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.RequiredHSTSPolicy> getRequiredHSTSPolicies();
  public java.util.List<io.fabric8.openshift.api.model.RequiredHSTSPolicy> buildRequiredHSTSPolicies();
  public io.fabric8.openshift.api.model.RequiredHSTSPolicy buildRequiredHSTSPolicy(java.lang.Integer index);
  public io.fabric8.openshift.api.model.RequiredHSTSPolicy buildFirstRequiredHSTSPolicy();
  public io.fabric8.openshift.api.model.RequiredHSTSPolicy buildLastRequiredHSTSPolicy();
  public io.fabric8.openshift.api.model.RequiredHSTSPolicy buildMatchingRequiredHSTSPolicy(java.util.function.Predicate<io.fabric8.openshift.api.model.RequiredHSTSPolicyBuilder> predicate);
  public java.lang.Boolean hasMatchingRequiredHSTSPolicy(java.util.function.Predicate<io.fabric8.openshift.api.model.RequiredHSTSPolicyBuilder> predicate);
  public A withRequiredHSTSPolicies(java.util.List<io.fabric8.openshift.api.model.RequiredHSTSPolicy> requiredHSTSPolicies);
  public A withRequiredHSTSPolicies(io.fabric8.openshift.api.model.RequiredHSTSPolicy... requiredHSTSPolicies);
  public java.lang.Boolean hasRequiredHSTSPolicies();
  public io.fabric8.openshift.api.model.IngressSpecFluent.RequiredHSTSPoliciesNested<A> addNewRequiredHSTSPolicy();
  public io.fabric8.openshift.api.model.IngressSpecFluent.RequiredHSTSPoliciesNested<A> addNewRequiredHSTSPolicyLike(io.fabric8.openshift.api.model.RequiredHSTSPolicy item);
  public io.fabric8.openshift.api.model.IngressSpecFluent.RequiredHSTSPoliciesNested<A> setNewRequiredHSTSPolicyLike(java.lang.Integer index,io.fabric8.openshift.api.model.RequiredHSTSPolicy item);
  public io.fabric8.openshift.api.model.IngressSpecFluent.RequiredHSTSPoliciesNested<A> editRequiredHSTSPolicy(java.lang.Integer index);
  public io.fabric8.openshift.api.model.IngressSpecFluent.RequiredHSTSPoliciesNested<A> editFirstRequiredHSTSPolicy();
  public io.fabric8.openshift.api.model.IngressSpecFluent.RequiredHSTSPoliciesNested<A> editLastRequiredHSTSPolicy();
  public io.fabric8.openshift.api.model.IngressSpecFluent.RequiredHSTSPoliciesNested<A> editMatchingRequiredHSTSPolicy(java.util.function.Predicate<io.fabric8.openshift.api.model.RequiredHSTSPolicyBuilder> predicate);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ComponentRoutesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ComponentRouteSpecFluent<io.fabric8.openshift.api.model.IngressSpecFluent.ComponentRoutesNested<N>>{
    public N and();
    public N endComponentRoute();
    
  }
  public interface RequiredHSTSPoliciesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.RequiredHSTSPolicyFluent<io.fabric8.openshift.api.model.IngressSpecFluent.RequiredHSTSPoliciesNested<N>>{
    public N and();
    public N endRequiredHSTSPolicy();
    
  }
  
}
